@@ -12,7 +12,7 @@ import subprocess
 try:
     import win32com
 except ModuleNotFoundError:
-    subprocess.run('pip install pypiwin32')
+    subprocess.run(['pip', 'install', 'pypiwin32'])
 
 import pythoncom
 from win32com.client import constants
@@ -46,13 +46,16 @@ class DocxTools:
         return pdf_file
 
     @classmethod
-    def merge(cls, master_file, toc):
+    def merge(cls, master_file, toc, *, subtoc='reduce'):
         """ 合并多份docx文件
 
         :param master_file: 要合并到哪个主文件
             注意如果这个文件已存在，会被替换，重置
         :param toc: 类似fitz的table of contents，用一个n*3的表格表示新文档的格式
             list，每个元素三列：标题级别，标题名称，(可选)对应文件内容
+        :param subtoc: 原来每份子文档里的标题，插入到新文档中的处理规则
+            reduce：降级
+            clear：清除
 
         这个功能还有些局限性，后面要扩展鲁棒性
         TODO 增加一个支持将原文档标题降级的功能，降到toc之后
@@ -72,7 +75,9 @@ class DocxTools:
             if file:
                 file = File(file)
                 member_doc = app.open_doc(file)
+
                 member_doc.Activate()
+
                 app.Selection.WholeStory()
                 app.Selection.Copy()
                 master_doc.Activate()
@@ -281,6 +286,7 @@ class EnchantWin32WordApplication(EnchantBase):
             doc = app.Documents.Add()
             EnchantWin32WordDocument.enchant(doc)
 
+            doc.Activate()
             rng = doc.Range()  # 全空的文档，有区间[0,1)
             EnchantWin32WordRange.enchant(rng)
 
@@ -303,15 +309,22 @@ class EnchantWin32WordApplication(EnchantBase):
             recursion_enchant: 是否递归执行enchant
 
         """
-        app = None
-        if mode == 'default':
+        if mode == 'Dispatch':
+            app = win32.Dispatch('WORD.APPLICATION')
+        elif mode == 'DispatchEx':
+            # 遇过win7+word2013，只能用DispatchEx的情况
+            app = win32.DispatchEx('WORD.APPLICATION')
+        elif mode == 'EnsureDispatch':
+            app = win32.gencache.EnsureDispatch('WORD.APPLICATION')
+        else:
             try:
-                app = win32.GetActiveObject('Word.Application')
+                # 名称用大写，会比较兼容旧的word2013等版本
+                app = win32.GetActiveObject('WORD.APPLICATION')
             except pythoncom.com_error:
                 app = None
         if app is None:
             # 必须用gencache方法，才能获得 from win32com.client import constants 的常量
-            app = win32.gencache.EnsureDispatch('Word.Application')
+            app = win32.gencache.EnsureDispatch('WORD.APPLICATION')
             # print('gencache')
         cls.enchant(app, recursion_enchant=recursion_enchant)
 
@@ -508,6 +521,14 @@ class EnchantWin32WordDocument(EnchantBase):
                     r = p.Range
                     doc.Range(r.Start, r.End - 1).InsertAfter(f'，{size}')
 
+    @staticmethod
+    def outline_demote(doc, level):
+        """ 标题降级，降低level层 """
+        for p in doc.Paragraphs:
+            name = p.Range.Style.NameLocal
+            m = re.match(r'标题 (\d)$', name)
+            lvl = int(m.groups(1))
+
 
 class EnchantWin32WordRange(EnchantBase):
     """ range是以下标0开始，左闭右开的区间
@@ -607,6 +628,7 @@ def rebuild_document_by_word(fmt='html', translate=False, navigation=False, visi
     app = EnchantWin32WordApplication.get_app(visible=visible)
     app.check_close(f)
     doc = app.new_doc(f)
+    doc.Activate()
     app.Selection.Paste()
 
     # 2 如果需要，也可以在这个阶段，插入word自动化的操作，而不是后续在html层面操作
