@@ -20,6 +20,7 @@ import fire
 
 from pyxllib.file.specialist import File, Dir, get_etag
 from pyxllib.debug.specialist import browser, TicToc, parse_datetime
+from pyxllib.text.specialist import BeautifulSoup
 
 
 def _print_df_result(df, outfmt='text'):
@@ -278,29 +279,10 @@ class UtoolsText(UtoolsBase):
 
     def browser(self):
         """ 将内容复制到word，另存为html文件后，用浏览器打开查看 """
-        from pyxllib.robot.win32lib import EnchantWin32WordApplication
+        from pyxllib.file.docxlib import rebuild_document_by_word
 
-        def _func(fmt='html', visible=False, quit=None):
-            """
-            Args:
-                fmt: 输出文件类型
-                    常见的可以简写：html、pdf、txt
-                    其他特殊需求可以用word原变量名：wdFormatDocument
-                visible: 是否展示运行过程，如果不展示，默认最后会close文档
-                quit: 运行完是否退出应用
-            """
-            # 保存的临时文件名采用etag
-            f = File(get_etag(self.cmds['ClipText']), Dir.TEMP, suffix=fmt)
-            app = EnchantWin32WordApplication.get_app(visible=visible)
-            doc = app.new_doc(f)
-            app.Selection.Paste()
-            doc.browser(fmt=fmt)
-            if not visible:
-                doc.Close()  # 关闭 word 文档
-            if quit:
-                app.Quit()
-
-        fire.Fire(_func, self.cmds['subinput'], 'browser')
+        file = fire.Fire(rebuild_document_by_word, self.cmds['subinput'], 'browser')
+        browser(file)
 
 
 class UtoolsRegex(UtoolsBase):
