@@ -169,6 +169,53 @@ def strfind(fullstr, objstr, *, start=None, times=0, overlap=False):
     return p
 
 
+def findspan(src, sub, start=0, end=None):
+    """ str.find的封装
+
+    :param sub:
+        str，普通的字符串查找
+        re.Pattern，正则模式的查找
+    :return: (start, end)
+        找不到的时候返回 (-1, -1)
+        否则返回区间的左开右闭位置
+    """
+    if end is None:
+        end = len(src)
+
+    if isinstance(sub, str):
+        pos = src.find(sub, start, end)
+    elif isinstance(sub, re.Pattern):
+        pattern = sub
+        m = pattern.search(src[start:end])
+        if m:
+            pos = m.start() + start
+            sub = m.group()
+        else:
+            pos = -1
+    else:
+        raise TypeError
+
+    if pos == -1:
+        return -1, -1
+    else:
+        return pos, pos + len(sub)
+
+
+def substr_count(src, sub, overlape=False):
+    """ 判断字符串src中符合pattern的字串有几个 """
+    if overlape:
+        raise NotImplementedError
+    else:
+        if isinstance(sub, str):
+            cnt = src.count(sub)
+        elif isinstance(sub, re.Pattern):
+            cnt = len(sub.findall(src))
+        else:
+            raise TypeError
+
+    return cnt
+
+
 class Stdout:
     """重定向标准输出流，切换print标准输出位置
 
@@ -775,3 +822,96 @@ class StrDiffType:
             return t
         else:
             return 16
+
+
+class BookContents:
+    """ 书本目录类 """
+
+    def __init__(self):
+        self.contents = []  # 目录条目按顺序保存在list中
+
+    def add(self, level, title, page=None):
+        """
+        Args:
+            level:
+            title:
+            page: 不一定要放整数的页数，也可以放其他一些比例之类的数值
+
+        Returns:
+
+        """
+        self.contents.append([level, title, page])
+
+    def format_numbers(self, number='normal', *, indent='', start_level=1, jump=False):
+        """ 每级目录的编号
+
+        :param number: 编号格式，目前有默认方式，以后有需要可以扩展其他模式
+        :param start_level: 开始展示的层级（高层级也会展示，只是不带编号和缩进）
+            可以设为负数，表示自动推算，比如-1
+        :param jump: 支持跳级，比如2级"3"，跳到4级本来是"3.0.1"，但开启该参数则会优化为"3.1"
+        :return: list，跟contents等长，表示每个标题的编号，可能为空''
+        """
+        # 1
+        if start_level == -1:
+            # 自动推算合适的开始编号
+            # -1模式，表示第一个不只一项的level
+            levels = [x[0] for x in self.contents]
+            levels_cnt = collections.Counter(levels)
+            for i in range(min(levels), max(levels) + 1):
+                if levels_cnt[i] > 1:
+                    start_level = i
+                    break
+
+        # 2
+        ls = []
+        ct = collections.defaultdict(int)
+        for x in self.contents:
+            # print(x)
+            level = x[0]
+            sign = indent * (level - start_level)
+
+            # 处理计数器
+            ct[level] += 1
+            for k, v in ct.items():
+                if k > level:
+                    ct[k] = 0
+
+            # 当前编号
+            if number == 'normal':
+                numbers = [ct[i] for i in range(start_level, level + 1)]
+                if jump:  # 过滤0
+                    numbers = [x for x in numbers if x]
+                sign += '.'.join(map(str, numbers))
+            else:
+                pass
+
+            ls.append(sign)
+
+        return ls
+
+    def format_str(self, indent='\t', *, number='normal', page=False, start_level=1, jump=False):
+        """ 转文本展示
+
+        :param indent: 每级展示的缩进量
+        :param page: 是否展示页码
+        """
+        numbers = self.format_numbers(number, indent=indent, start_level=start_level, jump=jump)
+
+        # 2
+        ls = []
+        for num, x in zip(numbers, self.contents):
+            level, title, page_ = x
+
+            # 标题
+            if level < start_level:
+                sign = title
+            else:
+                sign = ' '.join([num, x[1]])
+
+            # 加后缀
+            if page:
+                sign += f'，{page_}'
+
+            ls.append(sign)
+
+        return '\n'.join(ls)
